<?php
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
class MTWooFeaturedProductsSettingsPage
{
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    /**
     * Start up
     */
    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'mtw_plugin_menu' ) );
        add_action( 'admin_init', array( $this, 'mtw_settings_init' ) );
    }

    /**
     * Add options page
     */
    public function mtw_plugin_menu()
    {
        // This page will be under "Settings"
        add_options_page(
            'Settings', 
            'MT WooCommerce Featured Products', 
            'manage_options', 
            'mt_woocommerce_featured_products', 
            array( $this, 'create_admin_page' )
        );
    }

    /**
     * Options page callback
     */
    public function create_admin_page()
    {
        // Set class property
        $this->options = get_option( 'mt_featured_settings' );
        ?>
        <div class="wrap">
		
		<h1 class="wp-heading-inline">MT WooCommerce Featured Products Carousel</h1>
		
		<hr/>
		<p>&nbsp;</p>
		<h2>Shortcode Usage:</h2>
		<p><strong>Add to Page</strong> - [mt-featuredproducts]</p>
		<p><strong>Add to Template</strong> - &#60;?php echo do_shortcode('[mt-featuredproducts]'); ?&#62;</p>
		<p>&nbsp;</p>
		<hr/><p>&nbsp;</p>
            
            <form method="post" action="options.php">
            <?php
                // This prints out all hidden setting fields
				settings_fields( 'mtoption-group-1' );
				do_settings_sections( 'mt_woocommerce_featured_products' );;
                submit_button();
            ?>
            </form>
		<hr/>
		<p>&nbsp;</p>
		<p>For information on Order / Orderby settings see <a href="https://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">https://codex.wordpress.org/Class_Reference/WP_Query</a></p>
		<p>For information on Slick settings see <a href="http://kenwheeler.github.io/slick/" target="_blank">http://kenwheeler.github.io/slick/</a></p>
		
		<p>This plugin has been developed to display a Featured Products Carousel for WooCommerce 3+ using Slick developed by Ken Wheeler</p>
		<p style="text-align:right;margin-top:1.5em;">Version 1.0</p>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function mtw_settings_init()
    {          
        register_setting(
            'mtoption-group-1', // Option group
            'mt_featured_settings', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'options_section_id', // ID
            'Options', // Title
            array( $this, 'print_section_info' ), // Callback
            'mt_woocommerce_featured_products' // Page
        );  

        add_settings_field(
            'max_products', // ID
            'Maximum Number of Products', // Title 
            array( $this, 'products_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id' // Section           
        );      

        add_settings_field(
            'order', 
            'Order', 
            array( $this, 'order_callback' ), 
            'mt_woocommerce_featured_products', 
            'options_section_id'
        );    
        add_settings_field(
            'orderby', 
            'OrderBy', 
            array( $this, 'orderby_callback' ), 
            'mt_woocommerce_featured_products', 
            'options_section_id'
        );   
        add_settings_field(
            'slick-settings', 
            'Slick Settings', 
            array( $this, 'textarea_callback' ), 
            'mt_woocommerce_featured_products', 
            'options_section_id'
        );  		
    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize( $input )
    {
        $new_input = array();
        if( isset( $input['max_products'] ) )
            $new_input['max_products'] = sanitize_text_field( $input['max_products'] );
		if( isset( $input['order'] ) )
            $new_input['order'] = sanitize_text_field( $input['order'] );
		if( isset( $input['orderby'] ) )
            $new_input['orderby'] = sanitize_text_field( $input['orderby'] );
        if( isset( $input['slick-settings'] ) )
            $new_input['slick-settings'] = sanitize_text_field( $input['slick-settings'] );

        return $new_input;
    }

    /** 
     * Print the Section text
     */
    public function print_section_info()
    {
        print '';
    }

    /** 
     * Get the settings option array and print one of its values
     */
    public function products_callback()
    {
        printf(
            '<input type="number" id="max_products" name="mt_featured_settings[max_products]" value="%s" placeholder="-1" min="-1"/><br/><span style="font-size: 0.85em;">Default: All Featured Products</span>',
            isset( $this->options['max_products'] ) ? esc_attr( $this->options['max_products']) : ''
        );
    }
	public function order_callback()
    {
        printf(
            '<input type="text" id="order" name="mt_featured_settings[order]" value="%s" placeholder="ASC" /><br/><span style="font-size: 0.85em;">Default:  ASC<br/></strong><strong>Accepted Values:</strong> ASC / DESC</span>',
            isset( $this->options['order'] ) ? esc_attr( $this->options['order']) : ''
        );
    }
	public function orderby_callback()
    {
        printf(
            '<input type="text" id="orderby" name="mt_featured_settings[orderby]" value="%s" placeholder="title"/><br/><span style="font-size: 0.85em;">Default: title<br/><strong>Accepted Values:</strong> ID / author / title / name / date / rand</span>',
            isset( $this->options['orderby'] ) ? esc_attr( $this->options['orderby']) : ''
        );
    }
	    /** 
     * Get the settings option array and print one of its values
     */
    public function textarea_callback()
    {
        printf(
            '<textarea id="slick-settings" name="mt_featured_settings[slick-settings]" value="" rows="10" cols="50" placeholder="dots: true, &#10;arrows: false, &#10;infinite: false, &#10;speed: 300, &#10;slidesToShow: 3,&#10;slidesToScroll: 1, &#10;lazyLoad: \'ondemand\', &#10;autoplay: true, &#10;speed: 3000, &#10;autoplaySpeed: 3500,&#10; responsive: [ &#10;{ breakpoint: 768, &#10;settings: { &#10;slidesToShow: 2 &#10;} &#10;}, &#10;{ breakpoint: 480, &#10;settings: { &#10;slidesToShow: 1&#10; } &#10;} ]">%s</textarea>',
            isset( $this->options['slick-settings'] ) ? esc_attr( $this->options['slick-settings']) : ''
        );
    }
}

if( is_admin() )
    $my_settings_page = new MTWooFeaturedProductsSettingsPage();